from langchain_community.llms import Ollama

class ArticleRater:
    def __init__(self):
        self.client = "https://ai.fabelous.app/v1/ollama/generic"
        self.headers = self._load_token("Token.txt")

    def _load_token(self, token_path):
        with open(token_path, "r") as f:
            token = f.read().strip()
        return {"Authorization": f"Token {token}"}

    def get_response(self, article, result):
        ollama_params = {
            "base_url": self.client,
            "model": "mistral-nemo:12b-instruct-2407-q8_0",
            "headers": self.headers,
            "system": "Give a short explanation max 1-3 sentence why this article is rated like that. Begin the RESPONSE ALWAYS with the RESULT and the confidence"
        }

        message = (f"A Machine Learning Model labeled an article the following: "
                   f"Result: {result['result']}, Confidence: {result['confidence']}, The Article: {article}")

        # Initialize the Ollama object with the prepared parameters
        llm = Ollama(**ollama_params)

        # Return the response stream
        return llm.stream(message)

# Usage
if __name__ == "__main__":
    article_rater = ArticleRater()

    article = """Butler (dpo) - Erneutes Totalversagen beim Secret Service: Ausgerechnet in Butler, dem Ort des vorigen Anschlags auf Donald Trump, ist es gestern zu einem schweren Cringe-Attentat auf den republikanischen Präsidentschaftskandidaten gekommen. Einem Schwerbeknackten gelang es, die Bühne zu stürmen und neben Trump mehrere Luftsprünge zu machen.

Es sind Szenen, die sich nur schwer ertragen lassen: Zweimal hüpfte der 53-jährige Elon R. Musk manisch-euphorisch neben Trump in die Luft und präsentierte den Zuschauern dabei seinen Bauch. Danach hielt er eine extrem peinliche Rede, in der er Trump in den höchsten Tönen lobte.

Nach den verstörenden Bildern steht nun erneut der Secret Service in der Kritik. Nach Einschätzung vieler Experten hätten die Agenten die zahlreichen Red Flags hinsichtlich der Cringe-Gefahr für Trump sofort erkennen und Elon Musk mit gezielten Schüssen niederstrecken müssen.

"Wenn das nicht gelungen wäre, hätten sie sich spätestens, als Musk zum Luftsprung ansetzte, schützend vor den Kandidaten werfen müssen, um peinliche Pressebilder zu vermeiden", erklärt Sicherheitsanalyst Marc Tiede. "Das Versagen wiegt umso schwerer, weil es offenbar einzelne Zuschauer gab, die noch verzweifelt versuchten, die Agenten rechtzeitig vor Musk zu warnen, bevor die fatalen Sprünge fielen – vergeblich."

Derzeit ist noch unklar, wie es nach dem schweren Cringe-Attentat um den Präsidentschaftskandidaten steht. Laut Medienberichten steht jedoch zu befürchten, dass sich Trumps Rizz bis zur Wahl nicht wieder von diesem Anschlag erholen wird.

Der Secret Service und das FBI wollen jetzt Untersuchungen einleiten, wie es zu dem für alle Beteiligten höchst unangenehmen Vorfall kommen konnte.

Bizarr: Elon Musk befindet sich trotz seiner Tat nach wie vor auf freiem Fuß und könnte jederzeit wieder auf republikanischen Wahlkampfveranstaltungen für peinliche Momente sorgen."""
    result = {"result": "FAKE", "confidence": 0.9996}

    # Capture the stream response
    response_stream = article_rater.get_response(article, result)
    for chunk in response_stream:
        print(chunk, end='', flush=True)
